from aws_jupyter_proxy.handlers import setup_handlers


def _jupyter_server_extension_paths():
    return [{"module": "aws_jupyter_proxy"}]


def load_jupyter_server_extension(nbapp):
    setup_handlers(nbapp.web_app)



from botocore.session import Session
from notebook.utils import url_path_join

from aws_jupyter_proxy.awsproxy import create_endpoint_resolver, AwsProxyHandler
from aws_jupyter_proxy.awsconfig import AwsConfigHandler

awsproxy_handlers = [
    (
        "/awsproxy/awsconfig",
        AwsConfigHandler,
        None,
    ),
    (
        r"/awsproxy(.*)",
        AwsProxyHandler,
        dict(endpoint_resolver=create_endpoint_resolver(), session=Session()),
    ),
]


def setup_handlers(web_app):
    base_url = web_app.settings["base_url"]
    web_app.add_handlers(
        ".*",
        [
            (url_path_join(base_url, path), handler, data)
            for (path, handler, data) in awsproxy_handlers
        ],
    )



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="aws_jupyter_proxy",
    version="0.3.7",
    url="https://github.com/aws/aws-jupyter-proxy",
    author="Amazon Web Services",
    description="A Jupyter server extension to proxy requests with AWS SigV4 authentication",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    license="Apache License 2.0",
    install_requires=["notebook >=6.0, <7.0", "botocore >=1.0, <2.0"],
    extras_require={
        "dev": [
            "asynctest",
            "black",
            "pytest",
            "pytest-asyncio",
            "pytest-cov",
        ]
    },
    python_requires=">=3.6",
    data_files=[
        (
            "etc/jupyter/jupyter_notebook_config.d",
            ["aws_jupyter_proxy/etc/aws_jupyter_proxy.json"],
        )
    ],
    classifiers=["Development Status :: 4 - Beta"],
    include_package_data=True,
)
